##  Capturing Systems from ServiceNow
Since CMDBs are well-organized sources that maintain environment details and associated relationships, you can pull deployment information into SAP LeanIX.
In ServiceNow, environments are available through the ‘Application Services’ table ([CSDM 4.0![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.servicenow.com%2Fcommunity%2Fs%2Fcgfwn76974%2Fattachments%2Fcgfwn76974%2Fcommon-service-data-model-kb%2F243%2F1%2FCSDM%25204.0%2520Draft%2520V2.pdf "https://www.servicenow.com/community/s/cgfwn76974/attachments/cgfwn76974/common-service-data-model-kb/243/1/CSDM%204.0%20Draft%20V2.pdf")) or 'Service Instances' table ([CSDM 5.0![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.servicenow.com%2Fcommunity%2Fs%2Fcgfwn76974%2Fattachments%2Fcgfwn76974%2Fcommon-service-data-model-kb%2F744%2F3%2FCSDM%25205%2520w%2520links.pdf "https://www.servicenow.com/community/s/cgfwn76974/attachments/cgfwn76974/common-service-data-model-kb/744/3/CSDM%205%20w%20links.pdf")).
In the integration configuration, map this or any other relevant table to the system fact sheet with ServiceNow as the source.
The image below illustrates our recommended best-practice setup for the ServiceNow Integration:
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio43e771e00edc48b597d0b21669438bd1_HiRes.png)
**Note**
Obsolence risk from IT components is not aggregated through system fact sheets. For obsoloscence risk to be aggregated up to the application level, the IT components should be linked to the application fact sheets either directly or through other IT components. To learn more, see [Obsolescence Risk View Aggregation](https://help.sap.com/docs/leanix/ea/views-aggregation?locale=en-US&state=PRODUCTION&version=CLOUD#loio275dfd277a441014a04fa57db667a98c__obsolescence_risk_view_aggregation)
Recommended Mapping Configuration for ServiceNow Integration
